@@ -8,8 +8,8 @@
 ;; Package-Requires: ((emacs "25.1"))
 ;; Maintainer: James Cherti
 ;; Original Author: Andy Stewart
-;; Package-Version: 20260114.1535
-;; Package-Revision: 10be5e6d499d
+;; Package-Version: 20260221.311
+;; Package-Revision: d12901f87dd1
 ;; URL: https://github.com/jamescherti/quick-sdcv.el
 ;; Keywords: docs, startdict, sdcv
 
@@ -260,13 +260,23 @@ When ENABLED is nil: Deconstructs any symbol regions marked by '-->'."
         (decompose-region (match-beginning 0) (match-end 0)))))
 
   ;; Fontify the buffer
-  (when font-lock-mode
+  (when (and (bound-and-true-p font-lock-mode)
+             ;; For maximum safety during a session load, check
+             ;; `font-lock-set-defaults'. This variable guarantees that the
+             ;; font-lock machinery has actually finished configuring its
+             ;; keywords and syntax tables for the current buffer.
+             (bound-and-true-p font-lock-set-defaults))
     (save-restriction
       (widen)
-      (when (fboundp 'font-lock-flush)
-        (font-lock-flush))
-      (when (fboundp 'font-lock-ensure)
-        (font-lock-ensure)))))
+      (cond
+       ((and (fboundp 'font-lock-flush)
+             (fboundp 'font-lock-ensure))
+        (font-lock-flush)
+        (ignore-errors
+          (font-lock-ensure)))
+
+       ((fboundp 'jit-lock-fontify-now)
+        (jit-lock-fontify-now))))))
 
 (defun quick-sdcv--call-process (&rest arguments)
   "Call `quick-sdcv-program' with ARGUMENTS. Result is parsed as json."
